==> org-lsst-sal-camera-2.6.1-sources.jar: org/lsst/sal/camera/event/Image_handling_ImageHandler_GuiderConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Image_handling_ImageHandler_GuiderConfigurationEvent extends CameraEvent {
  private final String version;

  private final String imagehandlingconfig_guiderFITSFilePattern;

  private final String imagehandlingconfig_guiderLocations;

  private final String imagehandlingconfig_guiderPartition;

  public Image_handling_ImageHandler_GuiderConfigurationEvent(String version,
      String imagehandlingconfig_guiderFITSFilePattern, String imagehandlingconfig_guiderLocations,
      String imagehandlingconfig_guiderPartition) {
    this.version = version;
    this.imagehandlingconfig_guiderFITSFilePattern = imagehandlingconfig_guiderFITSFilePattern;
    this.imagehandlingconfig_guiderLocations = imagehandlingconfig_guiderLocations;
    this.imagehandlingconfig_guiderPartition = imagehandlingconfig_guiderPartition;
  }

  public String getVersion() {
    return version;
  }

  public String getImagehandlingconfig_guiderFITSFilePattern() {
    return imagehandlingconfig_guiderFITSFilePattern;
  }

  public String getImagehandlingconfig_guiderLocations() {
    return imagehandlingconfig_guiderLocations;
  }

  public String getImagehandlingconfig_guiderPartition() {
    return imagehandlingconfig_guiderPartition;
  }

  @Override
  public String toString() {
    return "Image_handling_ImageHandler_GuiderConfigurationEvent{" + "version=" + version +
        ", imagehandlingconfig_guiderFITSFilePattern=" + imagehandlingconfig_guiderFITSFilePattern +
        ", imagehandlingconfig_guiderLocations=" + imagehandlingconfig_guiderLocations +
        ", imagehandlingconfig_guiderPartition=" + imagehandlingconfig_guiderPartition +"}";
  }
}

==> org-lsst-sal-camera-2.6.3-sources.jar: org/lsst/sal/camera/event/Image_handling_ImageHandler_GuiderConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Image_handling_ImageHandler_GuiderConfigurationEvent extends CameraEvent {
  private final String version;

  private final String imagehandlingconfig_guiderFITSFilePattern;

  private final String imagehandlingconfig_guiderLocations;

  private final String imagehandlingconfig_guiderPartition;

  private final boolean imagehandlingconfig_includeRawStamps;

  public Image_handling_ImageHandler_GuiderConfigurationEvent(String version,
      String imagehandlingconfig_guiderFITSFilePattern, String imagehandlingconfig_guiderLocations,
      String imagehandlingconfig_guiderPartition, boolean imagehandlingconfig_includeRawStamps) {
    this.version = version;
    this.imagehandlingconfig_guiderFITSFilePattern = imagehandlingconfig_guiderFITSFilePattern;
    this.imagehandlingconfig_guiderLocations = imagehandlingconfig_guiderLocations;
    this.imagehandlingconfig_guiderPartition = imagehandlingconfig_guiderPartition;
    this.imagehandlingconfig_includeRawStamps = imagehandlingconfig_includeRawStamps;
  }

  public String getVersion() {
    return version;
  }

  public String getImagehandlingconfig_guiderFITSFilePattern() {
    return imagehandlingconfig_guiderFITSFilePattern;
  }

  public String getImagehandlingconfig_guiderLocations() {
    return imagehandlingconfig_guiderLocations;
  }

  public String getImagehandlingconfig_guiderPartition() {
    return imagehandlingconfig_guiderPartition;
  }

  public boolean isImagehandlingconfig_includeRawStamps() {
    return imagehandlingconfig_includeRawStamps;
  }

  @Override
  public String toString() {
    return "Image_handling_ImageHandler_GuiderConfigurationEvent{" + "version=" + version +
        ", imagehandlingconfig_guiderFITSFilePattern=" + imagehandlingconfig_guiderFITSFilePattern +
        ", imagehandlingconfig_guiderLocations=" + imagehandlingconfig_guiderLocations +
        ", imagehandlingconfig_guiderPartition=" + imagehandlingconfig_guiderPartition +
        ", imagehandlingconfig_includeRawStamps=" + imagehandlingconfig_includeRawStamps +"}";
  }
}
